@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 use base qw(Class::Accessor);
 use Crypt::OpenSSL::X509 qw(FORMAT_ASN1);
@@ -12,12 +12,12 @@ use Date::Parse;
 use DateTime;
 use DateTime::Duration;
 use Time::Duration::Parse;
+use UNIVERSAL::require;
 
 my $Socket = 'IO::Socket::INET6';
-eval "require $Socket";
-if ($@) {
+unless ($Socket->require) {
     $Socket = 'IO::Socket::INET';
-    eval "require $Socket";
+    $Socket->require or die $@;
 }
 
 __PACKAGE__->mk_accessors(qw(type target));
@@ -149,7 +149,7 @@ sub _peer_certificate {
     my $cert;
 
     no warnings 'once';
-    no strict 'refs';
+    no strict 'refs'; ## no critic
     *{$Socket.'::write_atomically'} = sub {
         my($self, $data) = @_;
 
@@ -359,12 +359,15 @@ Net::SSL::ExpireDate - obtain expiration date of certificate
     $ed = Net::SSL::ExpireDate->new( ssl   => 'example.com:995' ); # pop3s
     $ed = Net::SSL::ExpireDate->new( file  => '/etc/ssl/cert.pem' );
 
-    $expire_date = $ed->expire_date;         # return DateTime instance
+    if (defined $ed->expire_date) {
+      # do something
+      $expire_date = $ed->expire_date;         # return DateTime instance
 
-    $expired = $ed->is_expired;              # examine already expired
+      $expired = $ed->is_expired;              # examine already expired
 
-    $expired = $ed->is_expired('2 months');  # will expire after 2 months
-    $expired = $ed->is_expired(DateTime::Duration->new(months=>2));  # ditto
+      $expired = $ed->is_expired('2 months');  # will expire after 2 months
+      $expired = $ed->is_expired(DateTime::Duration->new(months=>2));  # ditto
+    }
 
 =head1 DESCRIPTION
 
